@@ -301,13 +301,34 @@ class SSHClient(object):
             f" {self.__ip}:{self.__port} | Success to copy file from remote {remote_path} to local host{local_path}:OK.")
         return True
 
+    @enter_and_leave_function
+    def ssh_is_active(self):
+        try:
+            if self.__ssh:
+                return self.__ssh.get_transport().is_active()
+            else:
+                return False
+        except Exception:
+            return False
+
+    @enter_and_leave_function
+    def sftp_is_active(self):
+        if not self.__ssh.get_transport() or not self.__ssh.get_transport().is_active():
+            return False
+        try:
+            self.__sftp.getcwd()
+            return True
+        except (paramiko.SSHException, IOError, OSError) as e:
+            log.warning(f"SFTP不可用: {e}")
+            return False
+
     @enter_and_leave_function
     def scp_file_to_local(self, remote_path, local_path,timeout=120):
         try:
-            if not self.__ssh:
+            if not self.ssh_is_active():
                 if not self.reconnect():
                     raise RuntimeError("ssh transport is not active and failed to reconnect.")
-            if not self.__sftp:
+            if not self.sftp_is_active:
                 self.__sftp = self.__ssh.open_sftp()
             return self._scp_file_to_local(remote_path, local_path)
         except Exception:
